from setuptools import setup, find_packages
import io
import os

here = os.path.abspath(os.path.dirname(__file__))

# Avoids IDE errors, but actual version is read from version.py
__version__ = None
exec(open("kidx_core/version.py").read())

# Get the long description from the README file
with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

tests_requires = [
    "pytest~=3.0",
    "pytest-pycodestyle~=1.3",
    "pytest-cov~=2.0",
    "pytest_localserver~=0.4.0",
    "treq~=17.0",
    "freezegun~=0.3.0",
    "nbsphinx>=0.3",
    "matplotlib~=2.0",
    "responses~=0.9.0",
    "httpretty~=0.9.0",
]

install_requires = [
    "jsonpickle~=1.0",
    "redis~=2.0",
    "fakeredis~=0.10.0",
    "pymongo~=3.7",
    "numpy~=1.16",
    "scipy~=1.2",
    "typing~=3.0",
    "requests~=2.20",
    "tensorflow~=1.12.0",
    "apscheduler~=3.0",
    "tqdm~=4.0",
    "networkx~=2.2",
    "fbmessenger~=5.0",
    "pykwalify~=1.7.0",
    "coloredlogs~=10.0",
    "ruamel.yaml~=0.15.0",
    "flask~=1.0",
    "flask_cors~=3.0",
    "scikit-learn~=0.20.0",
    "slackclient~=1.0",
    "python-telegram-bot~=11.0",
    "twilio~=6.0",
    "webexteamssdk~=1.0",
    "mattermostwrapper~=2.0",
    "rocketchat_API~=0.6.0",
    "colorhash~=1.0",
    "pika~=0.12.0",
    "jsonschema~=2.6",
    "packaging~=18.0",
    "gevent~=1.4",
    "pytz~=2018.9",
    "python-dateutil~=2.7",
    "kidx_nlu~=0.0.1a2",
    "kidx_core_sdk~=0.0.1a1",
    "colorclass~=2.2",
    "terminaltables~=3.1",
    "questionary>=1.0.1",
    "flask-jwt-simple~=0.0.3",
    "python-socketio~=3.0",
    "pydot~=1.4",
    "keras-applications==1.0.6",
    "keras-preprocessing==1.0.5"
]

extras_requires = {
    "test": tests_requires
}

setup(
    name="kidx-core",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        # supported python versions
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Software Development :: Libraries",
    ],
    packages=find_packages(exclude=["tests", "tools"]),
    version=__version__,
    install_requires=install_requires,
    tests_require=tests_requires,
    extras_require=extras_requires,
    include_package_data=True,
    description="Machine learning based dialogue engine "
                "for conversational software.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Kidx AI Technologies Education",
    author_email="nlp@mykidx.com",
    maintainer="Colin Gao",
    maintainer_email="colin.gao@mykidx.com",
    license="Apache 2.0",
    keywords="nlp machine-learning machine-learning-library bot bots "
             "botkit kidx conversational-agents conversational-ai chatbot"
             "chatbot-framework bot-framework",
    url="https://rasa.com",
    download_url="http://git.mykidx.com/nlp/kidx_core/-/archive"
                 "/{}/kidx_core-{}.tar.gz"
                 "".format(__version__, __version__),
    project_urls={
        "Bug Reports": "http://redmine.mykidx.com/projects/kidx-nlu/issues",
        "Source": "http://git.mykidx.com/nlp/kidx_core",
    },
)

print("\nWelcome to Kidx Core!")
print("If any questions please visit documentation "
      "page https://rasa.com/docs/core")
print("or join the community discussions on https://forum.rasa.com")
